@@ -3,7 +3,7 @@ package Firefox::Marionette::Capabilities;
 use strict;
 use warnings;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -76,6 +76,11 @@ sub moz_accessibility_checks {
     return $self->{moz_accessibility_checks};
 }
 
+sub proxy {
+    my ($self) = @_;
+    return $self->{proxy};
+}
+
 1;    # Magic true value required at end of module
 __END__
 
@@ -85,7 +90,7 @@ Firefox::Marionette::Capabilities - Represents Firefox Capabilities retrieved us
 
 =head1 VERSION
 
-Version 0.40
+Version 0.41
 
 =head1 SYNOPSIS
 
@@ -137,6 +142,10 @@ returns the page load strategy being used for the current session.  It will be o
 
 returns the current L<timeouts|Firefox::Marionette::Timeouts> object
 
+=head2 proxy
+
+returns the current L<proxy|Firefox::Marionette::Proxy> object
+
 =head2 browser_version 
 
 returns the version of L<firefox|https://firefox.com/>
