@@ -3,23 +3,13 @@ package Firefox::Marionette::Proxy;
 use strict;
 use warnings;
 
-our $VERSION = '0.98_07';
+our $VERSION = '0.41';
 
 sub new {
     my ( $class, %parameters ) = @_;
     if ( $parameters{pac} ) {
         $parameters{pac} = "$parameters{pac}";
     }
-    elsif ( $parameters{host} ) {
-        $parameters{type} = 'manual';
-        my $host = "$parameters{host}";
-        if ( $host !~ /:\d+$/smx ) {
-            $host .= q[:80];
-        }
-        $parameters{ftp}   = $host;
-        $parameters{http}  = $host;
-        $parameters{https} = $host;
-    }
     my $element = bless {%parameters}, $class;
     return $element;
 }
@@ -47,12 +37,7 @@ sub http {
 sub none {
     my ($self) = @_;
     if ( defined $self->{none} ) {
-        if ( ref $self->{none} ) {
-            return @{ $self->{none} };
-        }
-        else {
-            return ( $self->{none} );
-        }
+        return @{ $self->{none} };
     }
     else {
         return ();
@@ -83,7 +68,7 @@ Firefox::Marionette::Proxy - Represents a Proxy used by Firefox Capabilities usi
 
 =head1 VERSION
 
-Version 0.98_07
+Version 0.41
 
 =head1 SYNOPSIS
 
@@ -96,11 +81,6 @@ Version 0.98_07
         say "Browser will ignore the proxy for $address";
     }
 
-    # OR 
-
-    my $proxy = Firefox::Marionette::Proxy->new( host => 'squid.example.com:3128' );
-    my $firefox = Firefox::Marionette->new( capabilities => Firefox::Marionette::Capabilities->new( proxy => $proxy ) );
-
 =head1 DESCRIPTION
 
 This module handles the implementation of a Proxy in Firefox Capabilities using the Marionette protocol
@@ -115,9 +95,7 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =item * type - indicates the type of proxy configuration.  Must be one of 'pac', 'direct', 'autodetect', 'system', or 'manual'.
 
-=item * pac - defines the L<URI|URI> for a proxy auto-config file if the L<type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
-
-=item * host - defines the host for FTP, HTTP, and HTTPS traffic and sets the L<type|Firefox::Marionette::Proxy#type> to 'manual'.
+=item * pac - defines the L<URI|URI> for a proxy auto-config file if the <type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
 
 =item * http - defines the proxy host for HTTP traffic when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
 
@@ -141,7 +119,7 @@ returns the type of proxy configuration.  Must be one of 'pac', 'direct', 'autod
 
 =head2 pac
 
-returns the L<URI|URI> for a proxy auto-config file if the L<type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
+returns the L<URI|URI> for a proxy auto-config file if the <type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
 
 =head2 http
 
@@ -197,7 +175,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2018, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
